
$ErrorLog      = '/var/log/apache/error.log'; # Server's Error Log
$UnusualHeader = "Unusual Error Messages";
$ConfigHeader  = "Client Denied by Server Configuration";
$PermHeader    = "File Permissions Deny Access";
$ExistHeader   = "File Does Not Exist";

1;
