$zcommand    = 'gzip -9';
$zextension  = '.gz';

$wstatcmd    = 'wwwstat';

# Set up the filenames to be used

$ServerRoot = '/var/www';

$NewLog   = '/var/log/apache/access.log';    # Current logfile
$OldLog   = $NewLog . '.1';                    # and temp location

$PidFile  = '/var/run/apache.pid';;         # Server's PID file
$ErrorLog = '/var/log/apache/error.log';    # Server's Error Log

$TempLog = "/tmp/templog-$$.txt";      # Temporary file for last month's log

1;
